drama.shaders = {};
drama.shaders["blurvertical"] = {
	src: "varying mediump vec2 vTex;\nuniform mediump sampler2D samplerFront;\n\nuniform mediump vec2 pixelSize;\nuniform mediump float intensity;\n\nvoid main(void)\n{\n	mediump vec4 sum = vec4(0.0);\n	mediump float pixelHeight = pixelSize.y;\n	mediump float halfPixelHeight = pixelHeight / 2.0;	sum += texture2D(samplerFront, vTex - vec2(0.0, pixelHeight * 7.0 + halfPixelHeight)) * 0.06;\n	sum += texture2D(samplerFront, vTex - vec2(0.0, pixelHeight * 5.0 + halfPixelHeight)) * 0.10;\n	sum += texture2D(samplerFront, vTex - vec2(0.0, pixelHeight * 3.0 + halfPixelHeight)) * 0.13;\n	sum += texture2D(samplerFront, vTex - vec2(0.0, pixelHeight * 1.0 + halfPixelHeight)) * 0.16;\n	mediump vec4 front = texture2D(samplerFront, vTex);\n	sum += front * 0.10;\n	sum += texture2D(samplerFront, vTex + vec2(0.0, pixelHeight * 1.0 + halfPixelHeight)) * 0.16;\n	sum += texture2D(samplerFront, vTex + vec2(0.0, pixelHeight * 3.0 + halfPixelHeight)) * 0.13;\n	sum += texture2D(samplerFront, vTex + vec2(0.0, pixelHeight * 5.0 + halfPixelHeight)) * 0.10;\n	sum += texture2D(samplerFront, vTex + vec2(0.0, pixelHeight * 7.0 + halfPixelHeight)) * 0.06;\n	\n	gl_FragColor = mix(front, sum, intensity);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: false,
	parameters: [["intensity",0,1]]
};

drama.shaders["brightness"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float brightness;\n\nvoid main(void)\n{\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float a = front.a;\n	\n	if (a != 0.0)\n		front.rgb /= front.a;\n	\n	front.rgb += (brightness - 1.0);\n	\n	front.rgb *= a;\n	gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["brightness",0,1]]
};

drama.shaders["darken"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);\n	front.rgb /= front.a;\n	\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n	lowp vec4 back = texture2D(samplerBack, mix(destStart, destEnd, tex));\n	back.rgb /= back.a;	front.rgb = min(front.rgb, back.rgb) * front.a;\n	\n	gl_FragColor = front * back.a;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: false,
	parameters: []
};

drama.shaders["grayscale"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float intensity;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);	lowp float gray = front.r * 0.299 + front.g * 0.587 + front.b * 0.114;	gl_FragColor = mix(front, vec4(gray, gray, gray, front.a), intensity);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1]]
};

drama.shaders["grayscalemask"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\nuniform lowp float threshold;\n\nvoid main(void)\n{	lowp float fronta = texture2D(samplerFront, vTex).a;\n	\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n	lowp vec4 back = texture2D(samplerBack, mix(destStart, destEnd, tex));	lowp float gray = back.r * 0.299 + back.g * 0.587 + back.b * 0.114;	gl_FragColor = mix(back, vec4(gray, gray, gray, back.a), fronta);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: []
};

drama.shaders["setcolor"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp vec3 setColor;\n\nvoid main(void)\n{\n	lowp float a = texture2D(samplerFront, vTex).a;\n	\n	gl_FragColor = vec4(setColor.r * a, setColor.g * a, setColor.b * a, a);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["setColor",0,2]]
};

drama.shaders["warp"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform mediump float seconds;\nuniform mediump vec2 pixelSize;\nuniform mediump float layerScale;\n\nuniform mediump float freqX;\nuniform mediump float freqY;\nuniform mediump float ampX;\nuniform mediump float ampY;\nuniform mediump float speedX;\nuniform mediump float speedY;\n\nvoid main(void)\n{	mediump vec2 srcSize = srcEnd - srcStart;\n	mediump vec2 tex = ((vTex - srcStart) / srcSize);\n	mediump float aspect = pixelSize.y / pixelSize.x;\n	\n	mediump vec2 p = vTex;\n    p.x += (cos(tex.y * freqX / (pixelSize.x * 750.0) + (seconds * speedX)) * ampX * layerScale * pixelSize.x);\n	p.y += (sin(tex.x * freqY * aspect / (pixelSize.y * 750.0) + (seconds * speedY)) * ampY * layerScale * pixelSize.y);\n	\n	p = clamp(p, min(srcStart, srcEnd), max(srcStart, srcEnd));\n	\n	gl_FragColor = texture2D(samplerFront, p);\n}\n",
	extendBoxHorizontal: 30,
	extendBoxVertical: 30,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: true,
	parameters: [["freqX",0,0],["freqY",0,0],["ampX",0,0],["ampY",0,0],["speedX",0,0],["speedY",0,0]]
};
